@@ -64,8 +64,12 @@
 #' @template param_check_values
 #' @template param_callbacks
 #' @template param_internal_search_space
+#'
 #' @template param_xdt
 #' @template param_learner_param_vals
+#' @template param_internal_tuned_values
+#'
+#' @template field_internal_search_space
 #'
 #' @export
 #' @examples
@@ -102,8 +106,11 @@
 #' as.data.table(instance$archive)
 TuningInstanceBatchSingleCrit = R6Class("TuningInstanceBatchSingleCrit",
   inherit = OptimInstanceBatchSingleCrit,
+
   public = list(
 
+    internal_search_space = NULL,
+
     #' @description
     #' Creates a new instance of this [R6][R6::R6Class] class.
     initialize = function(
@@ -120,6 +127,7 @@ TuningInstanceBatchSingleCrit = R6Class("TuningInstanceBatchSingleCrit",
       ) {
       learner = assert_learner(as_learner(learner, clone = TRUE))
 
+      # tune token and search space
       if (!is.null(search_space) && length(learner$param_set$get_values(type = "only_token"))) {
         stop("If the values of the ParamSet of the Learner contain TuneTokens you cannot supply a search_space.")
       }
@@ -130,24 +138,30 @@ TuningInstanceBatchSingleCrit = R6Class("TuningInstanceBatchSingleCrit",
         search_space = as_search_space(search_space)
       }
 
-      # modifies tuning instance in-place and adds the internal tuning callback
-      res = init_internal_search_space(self, private, super, search_space, store_benchmark_result, learner,
-        callbacks, batch = TRUE)
+      # internal search space
+      internal_tune_ids = keep(names(search_space$tags), map_lgl(search_space$tags, function(tag) "internal_tuning" %in% tag))
+      if (length(internal_tune_ids)) {
+        self$internal_search_space = search_space$subset(internal_tune_ids)
 
-      private$.internal_search_space = res$internal_search_space
-      callbacks = res$callbacks
-      search_space = res$search_space
+        if (self$internal_search_space$has_trafo) {
+          stopf("Inner tuning and parameter transformations are currently not supported.")
+        }
+
+        search_space = search_space$subset(setdiff(search_space$ids(), internal_tune_ids))
+
+        # the learner dictates how to interpret the to_tune(..., inner)
+        learner$param_set$set_values(.values = learner$param_set$convert_internal_search_space(self$internal_search_space))
+      }
 
       # create codomain from measure
       measures = assert_measures(as_measures(measure, task_type = task$task_type), task = task, learner = learner)
       codomain = measures_to_codomain(measures)
 
-
       archive = ArchiveBatchTuning$new(
         search_space = search_space,
         codomain = codomain,
         check_values = check_values,
-        internal_search_space = private$.internal_search_space
+        internal_search_space = self$internal_search_space
       )
 
       objective = ObjectiveTuningBatch$new(
@@ -159,7 +173,8 @@ TuningInstanceBatchSingleCrit = R6Class("TuningInstanceBatchSingleCrit",
         store_models = store_models,
         check_values = check_values,
         archive = archive,
-        callbacks = callbacks)
+        callbacks = callbacks,
+        internal_search_space = self$internal_search_space)
 
       super$initialize(
         objective = objective,
@@ -169,22 +184,35 @@ TuningInstanceBatchSingleCrit = R6Class("TuningInstanceBatchSingleCrit",
         archive = archive)
     },
 
+
     #' @description
     #' The [Tuner] object writes the best found point and estimated performance value here.
     #' For internal use.
     #'
     #' @param y (`numeric(1)`)\cr
     #'   Optimal outcome.
-    assign_result = function(xdt, y, learner_param_vals = NULL) {
+    #' @param ... (`any`)\cr
+    #' ignored.
+    assign_result = function(xdt, y, learner_param_vals = NULL, ...) {
       # set the column with the learner param_vals that were not optimized over but set implicitly
       assert_list(learner_param_vals, null.ok = TRUE, names = "named")
 
+      # learner param values
       if (is.null(learner_param_vals)) {
         learner_param_vals = self$objective$learner$param_set$values
       }
       opt_x = unlist(transform_xdt_to_xss(xdt, self$search_space), recursive = FALSE)
       learner_param_vals = insert_named(learner_param_vals, opt_x)
 
+      # disable internal tuning
+      if (!is.null(xdt$internal_tuned_values)) {
+        learner = self$objective$learner$clone(deep = TRUE)
+        learner_param_vals = insert_named(learner_param_vals, xdt$internal_tuned_values[[1]])
+        learner$param_set$set_values(.values = learner_param_vals)
+        learner$param_set$disable_internal_tuning(self$internal_search_space$ids())
+        learner_param_vals = learner$param_set$values
+      }
+
       # maintain list column
       if (length(learner_param_vals) < 2 | !nrow(xdt)) learner_param_vals = list(learner_param_vals)
 
@@ -198,17 +226,10 @@ TuningInstanceBatchSingleCrit = R6Class("TuningInstanceBatchSingleCrit",
     #' Param values for the optimal learner call.
     result_learner_param_vals = function() {
       private$.result$learner_param_vals[[1]]
-    },
-    #' @field internal_search_space ([paradox::ParamSet])\cr
-    #'   The search space containing those parameters that are internally optimized by the [`mlr3::Learner`].
-    internal_search_space = function(rhs) {
-      assert_ro_binding(rhs)
-      private$.internal_search_space
     }
   ),
 
   private = list(
-    .internal_search_space = NULL,
     # initialize context for optimization
     .initialize_context = function(optimizer) {
       context = ContextBatchTuning$new(self, optimizer)
@@ -216,3 +237,4 @@ TuningInstanceBatchSingleCrit = R6Class("TuningInstanceBatchSingleCrit",
     }
   )
 )
+
