@@ -21,7 +21,6 @@
 #' @template param_store_models
 #' @template param_check_values
 #' @template param_callbacks
-#' @template param_validate
 #' @template param_rush
 #'
 #' @export
@@ -48,7 +47,6 @@ auto_tuner = function(
   store_models = FALSE,
   check_values = FALSE,
   callbacks = NULL,
-  validate = NULL,
   rush = NULL
   ) {
   terminator = terminator %??% terminator_selection(term_evals, term_time)
@@ -65,6 +63,5 @@ auto_tuner = function(
     store_models = store_models,
     check_values = check_values,
     callbacks = callbacks,
-    validate = validate,
     rush = rush)
 }
